##
##  tidy.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2017 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_tidy 20120821
%define       V_perl 1.60

#   package information
Name:         tidy
Summary:      HTML Tidy
URL:          http://w3c.github.io/tidy-html5/
Vendor:       Dave Raggett
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        PLUS
Group:        HTML
License:      GPL
Version:      %{V_tidy}
Release:      20170915

#   package options
%option       with_perl  no

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/tidy/tidy-html5-%{V_tidy}.tar.gz
Source1:      http://www.cpan.org/modules/by-module/HTML/HTML-Tidy-%{V_perl}.tar.gz
Patch0:       tidy.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, make, libxslt
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_perl}" == "yes"
BuildPreReq:  perl, perl-openpkg
PreReq:       perl
%endif

%description
    This is a HTML/XHTML markup code cleaning tool.

%track
    prog tidy:tidy = {
        version   = %{V_tidy}
        url       = http://download.openpkg.org/components/versioned/tidy/
        regex     = tidy-html5-(__VER__)\.tar\.gz
    }
    prog tidy:perl = {
        version   = %{V_perl}
        url       = http://www.cpan.org/modules/by-module/HTML/
        regex     = HTML-Tidy-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n tidy-html5
%if "%{with_perl}" == "yes"
    %setup -q -n tidy-html5 -T -D -a 1
%endif
    %patch -p0

%build
    ( cd build/gmake
      %{l_make} %{l_mflags} \
          CC="%{l_cc} %{l_cflags -O}"
    ) || exit $?
    ( cd htmldoc
      ../bin/tidy -xml-help   >tidy.xml
      ../bin/tidy -xml-config >tidy-config.xml
      %{l_prefix}/bin/xsltproc tidy1.xsl tidy.xml >tidy.1
    ) || exit $?
%if "%{with_perl}" == "yes"
    %{l_shtool} subst \
        -e "s;-ltidyp;-L`pwd`/../tidy-html5/lib -ltidy;" \
        -e "s;-I/usr/local/include/tidyp;-I`pwd`/../tidy-html5/include;" \
        -e "s;-I/usr/include/tidyp;-I`pwd`/../tidy-html5/include;" \
        HTML-Tidy-%{V_perl}/Makefile.PL
    %{l_shtool} subst \
        -e 's;tidyp.h;tidy.h;g' \
        HTML-Tidy-%{V_perl}/Tidy.xs
    %{l_prefix}/bin/perl-openpkg prepare
    %{l_prefix}/bin/perl-openpkg -d HTML-Tidy-%{V_perl} configure build
%endif

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/include/tidy \
        $RPM_BUILD_ROOT%{l_prefix}/lib \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_shtool} install -c -s -m 755 \
        bin/tidy $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        lib/libtidy.a $RPM_BUILD_ROOT%{l_prefix}/lib/
    %{l_shtool} install -c -m 644 \
        include/*.h $RPM_BUILD_ROOT%{l_prefix}/include/tidy/
    %{l_shtool} install -c -m 644 \
        htmldoc/tidy.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
%if "%{with_perl}" == "yes"
    %{l_prefix}/bin/perl-openpkg -d HTML-Tidy-%{V_perl} install
    %{l_prefix}/bin/perl-openpkg -F perl-openpkg-files fixate cleanup
%else
    >perl-openpkg-files
%endif
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} `cat perl-openpkg-files`

%files -f files

%clean

